#!/bin/sh

show_help()
{
  cat <<EOF
Usage:
  ppp-conect.sh -a <auth> -i <iface> -s <server> -n <service> -u <user> -p <spass> -l <lpass>
  <auth>      pap, chap, chapb - server have to authentificate on peer aka  bidirectional chap
  <iface>     interface name
  <server>    Server Name
  <service>   ppp Service Name
  <user>      user name
  <spass>     password
  <lpass>     local system password, server authentificate on local
EOF

}

PIPE="/tmp/pipe"

while getopts 'a:i:s:n:u:p:l:' OPTION
do
  case $OPTION in
    a) AUTH=$OPTARG
    ;;
    i) IFACE=$OPTARG
    ;;
    s) SERVER=$OPTARG
    ;;
    n) SERVICE_NAME=$OPTARG
    ;;
    u) SUSER=$OPTARG
    ;;
    p) SPASS=$OPTARG
    ;;
    l) LPASS=$OPTARG
    ;;
esac
done

if [ -z "$AUTH" ] || [ "$AUTH" = "auth type" ] ; then
    echo "NO AUTH TYPE"
    show_help
    exit 1
fi

if [ "$AUTH" = chapb ]; then
    AUTHTYPE=chap
    AUTH=auth
else
    AUTHTYPE="$AUTH"
    AUTH=noauth
fi

if [ -z "$IFACE" ] || [ "$IFACE" = Interface ] ; then
    echo "NO IFACE"
    show_help
    exit 1
fi

if [ -z "$SUSER" ] ; then
    echo "NO USER"
    show_help
    exit 1
fi

if [ -z "$SERVER" ] ; then
    echo "NO SERVER"
    show_help
    exit 1
fi

if [ -z "$SERVICE_NAME" ] ; then
    echo "NO SERVICE NAME"
    show_help
    exit 1
fi

if [ -z "$SPASS" ] ; then
    echo "NO PASSWORD"
    show_help
    exit 1
fi

if [ "$AUTH" = auth ] && [ -z "$LPASS" ] ; then
    echo "NO LOCAL SYSTEM PASSWORD"
    show_help
    exit 1
fi

ret=`/sbin/lsmod | grep pppoe`

if [ -z "$ret" ] ; then
    /sbin/modprobe pppoe

    ret=`/sbin/lsmod | grep pppoe`

    if [ -z "$ret" ] ; then
    	echo "FAILED TO LOAD PPPOE MODULE"
    	exit 1
    fi
fi

ret=`/sbin/ifconfig | grep $IFACE`

if [ -z "$ret" ]
then
    echo "$IFACE IS NOT UP"
    sudo /sbin/ifconfig $IFACE up >/dev/null 2>&1
    
    ret=`/sbin/ifconfig | grep $IFACE`
    if [ -z "$ret" ]; then
    	echo "FAILED TO UP $IFACE"
    	exit 1
    fi
fi

SYSTEM_PATH=/home/user/system

PAPSECFILE=$SYSTEM_PATH/pap-secrets
rm -f $PAPSECFILE
CHAPSECFILE=$SYSTEM_PATH/chap-secrets
rm -f $CHAPSECFILE
APPLY_AUTH=/usr/local/bin/apply_auth.sh

if [ "$AUTHTYPE" = pap ] ; then
    echo -e "$SUSER\t$SERVER\t$SPASS\t*" > $PAPSECFILE
    $APPLY_AUTH $PAPSECFILE
else
    echo -e "$SUSER\t$SERVER\t$SPASS\t*" > $CHAPSECFILE
    if [ "$AUTH" = auth ] ; then
        echo -e "$SERVER\t$SUSER\t$LPASS\t*" >> $CHAPSECFILE
    fi
    $APPLY_AUTH $CHAPSECFILE
fi

CONF_PPPOE=/usr/local/bin/conf_pppoe.sh
CONF_FILE=/etc/ppp/pppoe.conf
$CONF_PPPOE $CONF_FILE $SERVICE_NAME $IFACE $SUSER

CONF_OPTS=/usr/local/bin/conf_ppp_opts.sh
OPT_FILE=/etc/ppp/options
$CONF_OPTS $OPT_FILE $AUTH 

command="/usr/bin/setsid sudo /usr/sbin/pppd pty 'sudo /usr/sbin/pppoe -p \
/var/run/pppoe.pid -I $IFACE -T 80 -U  -m 1412  \
-S $SERVICE_NAME' noipdefault $AUTH default-asyncmap \
defaultroute hide-password nodetach  mtu 1492 mru 1492 \
noaccomp nodeflate nopcomp novj novjccomp nomppe user $SUSER \
lcp-echo-interval 20 lcp-echo-failure 3 debug >$PIPE 2>&1 &"

rm -f $PIPE
mkfifo $PIPE
echo "$command"
eval $command
echo $! > /var/run/pppd.pid
cat $PIPE

