. /usr/local/libexec/platform_lib.sh


CARDTYPE=""


rev1_get_card_state()
{
  local slot=${1}

  PWR_STATE=`grep "Shortpwr" /sys/devices/platform/pmmcu.0/card${slot} | awk '{print $2}'`
  USB_STATE=`grep "Short5V" /sys/devices/platform/pmmcu.0/card${slot} | awk '{print $2}'`

  CARD_STATE=`grep state /sys/devices/platform/pmmcu.0/card${slot} | awk '{print $2}'`

  for LINE in "PWR" "USB"; do
    STATE=`eval echo \\$${LINE}_STATE`
    if [ "$STATE" == "present" ]; then
      CARD_STATE="hwfault"
    fi
  done

}

rev2_get_card_state()
{
  local slot=${1}

  local slot_plus_one=$slot
  let slot_plus_one++

  if [ ${slot} -eq 0 ]; then
    get_gpio_value $CARD0_STATUS_GPIO
  else
    get_gpio_value $CARD1_STATUS_GPIO
  fi

  # we have inverted logic here: 0 means insert, 1 means absent
  if [ $? -eq 0 ]; then
    CARD_STATE="inserted"
  else
    CARD_STATE="absent"
  fi

  # Check for hardware faults (nVCC_{PWR,USB}_FAULT{1,2})
  # USB should present, but its always invalid on rev2
  for LINE in "PWR"; do                                                   
    eval get_gpio_value \$nVCC_${LINE}_FAULT${slot_plus_one}
    if [ $? -eq 0 ]; then      
      CARD_STATE="hwfault"                                                      
    fi                                                                          
  done                                                                          

}

get_card_type()
{
  local slot=${1}
  PRODUCTID=`grep -A 2 -e "Port=0${slot}" /proc/bus/usb/devices | grep -e '^P: *Vendor=[10]3eb'|sed 's/ /\n/g'|grep ProdID| awk -F= '{print $2}'`

  case $PRODUCTID in
    "6124")
      CARDTYPE="e1"
      ;;
    "6128")
      CARDTYPE="da"
      ;;
    "6127")
      CARDTYPE="otdr"
      ;;
    "6125")
      CARDTYPE="gbe"
      ;;
    "6129")
      CARDTYPE="e0"
      ;;
    "6130")
      CARDTYPE="vf"
      ;;
  esac
}

get_card_state()
{
  local slot=${1}

  if [ ${BOARD_REV} -eq 1 ]; then
    rev1_get_card_state ${slot}
  else
    rev2_get_card_state ${slot}
  fi

}

get_card_info()
{
  local slot=${1}
  get_card_type ${slot}

  local SERIAL=`grep -A 5 -e "Port=0${slot}" /proc/bus/usb/devices | grep -e '^S: *SerialNumber' | awk '{print $2}' | awk -F= '{print $2}'`

  echo "${CARDTYPE} ${SERIAL}"
}

get_mcu_fw_file()
{
  MCU=`ls /lib/firmware/exp-${CARDTYPE}*.bin 2> /dev/null  | awk '{print $1}'`
}

get_fpga_fw_file()
{
  FPGA=`ls /lib/firmware/exp-${CARDTYPE}*.rbf 2> /dev/null | awk '{print $1}'`
}

get_mcu_fw_version()
{
  MCU_VER=`echo "$MCU" | awk -F_ '{print $2}' | awk -F.bin '{print $1}'`
}

get_fpga_fw_version()
{
  FPGA_VER=`echo "$FPGA" | awk -F_ '{print $2}' | awk -F.rbf '{print $1}'`
}

rev1_put_card_to_dfu()
{
  local slot=${1}
  #entering dfu
  echo dfu > /sys/devices/platform/pmmcu.0/card$slot
}

rev2_put_card_to_dfu()
{
  local slot=${1}

  if [ ${slot} -eq 0 ]; then
    set_gpio_value $CARD0_PGM_GPIO 1
  else
    set_gpio_value $CARD1_PGM_GPIO 1
  fi

  reboot_card ${slot}

  sleep 1

  if [ ${slot} -eq 0 ]; then
    set_gpio_value $CARD0_PGM_GPIO 0
  else
    set_gpio_value $CARD1_PGM_GPIO 0
  fi
}

put_card_to_dfu()
{
  local slot=${1}
  if [ ${BOARD_REV} -eq 1 ]; then
    rev1_put_card_to_dfu ${slot}
  else
    rev2_put_card_to_dfu ${slot}
  fi
}

rev1_turn_off_card()
{
  local slot=${1}
  echo off > /sys/devices/platform/pmmcu.0/card${slot}
}

rev1_turn_on_card()
{
  local slot=${1}
  echo on > /sys/devices/platform/pmmcu.0/card${slot}
}

rev1_reboot_card()
{
  local slot=${1}
  rev1_turn_off_card ${slot}
  sleep 1
  rev1_turn_on_card ${slot}
}

rev2_turn_off_card()
{
  local slot=`expr 1 + ${1}`
  /usr/local/bin/uppoff ${slot} 0 > /dev/null

  if [ $slot -eq 1 ]; then
    set_gpio_value $CARD0_VCC_nEN 1
  else
    set_gpio_value $CARD1_VCC_nEN 1
  fi
}

rev2_turn_on_card()
{
  local slot=`expr 1 + ${1}`

  /usr/local/bin/uppoff ${slot} 1 > /dev/null
  
  # emperically found :( 
  # may not work without it.
  sleep 1

  if [ $slot -eq 1 ]; then
    set_gpio_value $CARD0_VCC_nEN 0
  else
    set_gpio_value $CARD1_VCC_nEN 0
  fi
}

rev2_reboot_card()
{
  local slot=${1}
  rev2_turn_off_card ${slot}
  
  # emperically found :( 
  # may not work without it.
  sleep 2
  rev2_turn_on_card ${slot}
}

reboot_card()
{
  local slot=${1}
  if [ ${BOARD_REV} -eq 1 ]; then
    rev1_reboot_card ${slot}
  else
    rev2_reboot_card ${slot}
  fi
}
